#
# spec file for package ghc-cryptonite
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name cryptonite
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.30
Release:        2.17
Summary:        Cryptography Primitives sink
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-basement-devel
BuildRequires:  ghc-basement-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-memory-devel
BuildRequires:  ghc-memory-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  glibc-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-kat-devel
BuildRequires:  ghc-tasty-kat-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
%endif

%description
A repository of cryptographic primitives.

* Symmetric ciphers: AES, DES, 3DES, CAST5, Blowfish, Twofish, Camellia, RC4,
Salsa, XSalsa, ChaCha.

* Hash: SHA1, SHA2, SHA3, SHAKE, MD2, MD4, MD5, Keccak, Skein, Ripemd, Tiger,
Whirlpool, Blake2

* MAC: HMAC, KMAC, Poly1305

* Asymmetric crypto: DSA, RSA, DH, ECDH, ECDSA, ECC, Curve25519, Curve448,
Ed25519, Ed448

* Key Derivation Function: PBKDF2, Scrypt, HKDF, Argon2, BCrypt, BCryptPBKDF

* Cryptographic Random generation: System Entropy, Deterministic Random
Generator

* Data related: Anti-Forensic Information Splitter (AFIS)

If anything cryptographic related is missing from here, submit a pull request
to have it added. This package strives to be a cryptographic kitchen sink that
provides cryptography for everyone.

Evaluate the security related to your requirements before using.

Read "Crypto.Tutorial" for a quick start guide.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires:       glibc-devel
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%define cabal_configure_options -f-support_aesni -f-support_rdrand -f-support_sse
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Mar 13 2022 Peter Simons <psimons@suse.com>
- Update cryptonite to version 0.30.
  [#]# 0.30
  * Fix some C symbol blake2b prefix to be cryptonite_ prefix (fix mixing with other C library)
  * add hmac-lazy
  * Fix compilation with GHC 9.2
  * Drop support for GHC8.0, GHC8.2, GHC8.4, GHC8.6
  [#]# 0.29
  * advance compilation with gmp breakage due to change upstream
  * Add native EdDSA support
* Sat May  8 2021 psimons@suse.com
- Update cryptonite to version 0.29.
  Upstream has not updated the file "CHANGELOG.md" since the last
  release.
* Wed Jan 27 2021 psimons@suse.com
- Update cryptonite to version 0.28.
  [#]# 0.28
  * Add hash constant time capability
  * Prevent possible overflow during hashing by hashing in 4GB chunks
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Mon Jun 22 2020 psimons@suse.com
- Update cryptonite to version 0.27.
  [#]# 0.27
  * Optimise AES GCM and CCM
  * Optimise P256R1 implementation
  * Various AES-NI building improvements
  * Add better ECDSA support
  * Add XSalsa derive
  * Implement square roots for ECC binary curve
  * Various tests and benchmarks
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Wed May 22 2019 psimons@suse.com
- Update cryptonite to version 0.26.
  [#]# 0.26
  * Add Rabin cryptosystem (and variants)
  * Add bcrypt_pbkdf key derivation function
  * Optimize Blowfish implementation
  * Add KMAC (Keccak Message Authentication Code)
  * Add ECDSA sign/verify digest APIs
  * Hash algorithms with runtime output length
  * Update blake2 to latest upstream version
  * RSA-PSS with arbitrary key size
  * SHAKE with output length not divisible by 8
  * Add Read and Data instances for Digest type
  * Improve P256 scalar primitives
  * Fix hash truncation bug in DSA
  * Fix cost parsing for bcrypt
  * Fix ECC failures on arm64
  * Correction to PKCS#1 v1.5 padding
  * Use powModSecInteger when available
  * Drop GHC 7.8 and GHC 7.10 support, refer to pkg-guidelines
  * Optimise GCM mode
  * Add little endian serialization of integer
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update cryptonite to version 0.25.
  * Improve digest binary conversion efficiency
  * AES CCM support
  * Add MonadFailure instance for CryptoFailable
  * Various misc improvements on documentation
  * Edwards25519 lowlevel arithmetic support
  * P256 add point negation
  * Improvement in ECC (benchmark, better normalization)
  * Blake2 improvements to context size
  * Use gauge instead of criterion
  * Use haskell-ci for CI scripts
  * Improve Digest memory representation to be 2 less Ints and one less boxing
    moving from `UArray` to `Block`
  * Ed25519: generateSecret & Documentation updates
  * Repair tutorial
  * RSA: Allow signing digest directly
  * IV add: fix overflow behavior
  * P256: validate point when decoding
  * Compilation fix with deepseq disabled
  * Improve Curve448 and use decaf for Ed448
  * Compilation flag blake2 sse merged in sse support
  * Process unaligned data better in hashes and AES, on architecture needing alignment
  * Drop support for ghc 7.6
  * Add ability to create random generator Seed from binary data and
    loosen constraint on ChaChaDRG seed from ByteArray to ByteArrayAccess.
  * Add 3 associated types with the HashAlgorithm class, to get
    access to the constant for BlockSize, DigestSize and ContextSize at the type level.
    the related function that this replaced will be deprecated in later release, and
    eventually removed.
  API CHANGES:
  * Improve ECDH safety to return failure for bad inputs (e.g. public point in small order subgroup).
    To go back to previous behavior you can replace `ecdh` by `ecdhRaw`. It's recommended to
    use `ecdh` and handle the error appropriately.
  * Users defining their own HashAlgorithm needs to define the
    HashBlockSize, HashDigest, HashInternalContextSize associated types
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 0.23.
* Wed Jan 18 2017 psimons@suse.com
- Update to version 0.21 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.19 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.15 revision 0 with cabal2obs.
* Sun Apr 10 2016 mimi.vx@gmail.com
- update to 0.14
  * Fix serialization of DH and ECDH
  * Reduce size of SHA3 context instead of allocating all-size fit memory. save up to
    72 bytes of memory per context for SHA3-512.
  * Add a Seed capability to the main DRG, to be able to debug/reproduce randomized
    program where you would want to disable the randomness.
  * Add support for Cipher-based Message Authentication Code (CMAC) (Kei Hibino)
  * CHANGE Change the SharedKey for Crypto.PubKey.DH and Crypto.PubKey.ECC.DH, from
    an Integer newtype to a ScrubbedBytes newtype. Prevent mistake where the bytes
    representation is generated without the right padding (when needed).
  * CHANGE Keep The field size in bits, in the Params in Crypto.PubKey.DH, moving
    from 2 elements to 3 elements in the structure.
* Mon Feb 22 2016 mimi.vx@gmail.com
- update to 0.13
  * SECURITY Fix buffer overflow issue in SHA384, copying 16 extra bytes from
    the SHA512 context to the destination memory pointer leading to memory
    corruption, segfault
  * Fix compilation issue with Ed448 on 32 bits machine.
* Sun Feb 14 2016 mimi.vx@gmail.com
- update to 0.11
  * Truncate hashing correctly for DSA
  * Add support for HKDF (RFC 5869)
  * Add support for Ed448
  * Extends support for Blake2s to 224 bits version.
  * Compilation fix with AESNI and ghci compiling C source in a weird order.
  * Fix example compilation, typo, and warning
* Fri Dec 25 2015 mimi.vx@gmail.com
- update to 0.10
- drop blake2-fix.patch
  * Add reference implementation of blake2 for non-SSE2 platfom
  * Add support_blake2_sse flag
* Tue Dec 15 2015 mimi.vx@gmail.com
- update to 0.9
  * Quiet down unused module imports
  * Move Curve25519 over to Crypto.Error instead of using Either String.
  * Add documentation for ChaChaPoly1305
  * Add missing documentation for various modules
  * Add a way to create Poly1305 Auth tag.
  * Added support for the BLAKE2 family of hash algorithms
  * Fix endianness of incrementNonce function for ChaChaPoly1305
  * Add support for ChaChaPoly1305 Nonce Increment
  * Add PKCS5 / PKCS7 padding and unpadding methods
  * Fix ChaChaPoly1305 Decryption
  * Add support for BCrypt
- add blake2-fix.patch and disabled build of sse4.1 optimized blake2
* Thu Aug  6 2015 mimi.vx@gmail.com
- initial commit
